@@ -10,9 +10,9 @@ def get_timestamp():
     return datetime.datetime.utcnow()
 
 def generate_pkg_name(name):
-    return "mavlink_" + name + "_msgs"
+    return "mavlink_" + name + ""
 
-def generate_file(filename,content):
+def generate_file(filename, content):
     #===========================================================================
     # write a file to disk
     #===========================================================================
@@ -29,4 +29,4 @@ def mk_dirs(dirname):
         os.makedirs(dirname)
     except OSError, e:
         if e.errno != errno.EEXIST:
-            raise
\ No newline at end of file
+            raise
